summaryrefslogtreecommitdiff
path: root/FreeRTOS/Demo/CORTEX_M7_STM32F7_STM32756G-EVAL_IAR_Keil
diff options
context:
space:
mode:
authorrtel <rtel@1d2547de-c912-0410-9cb9-b8ca96c0e9e2>2016-04-04 14:53:04 +0000
committerrtel <rtel@1d2547de-c912-0410-9cb9-b8ca96c0e9e2>2016-04-04 14:53:04 +0000
commite90329865b5e0a8ed6391a2d05ef863139dd5533 (patch)
tree54434cb9a50dfe9d432c6e92467cf7104d43f8c1 /FreeRTOS/Demo/CORTEX_M7_STM32F7_STM32756G-EVAL_IAR_Keil
parent05067b72f3b2b6e82faf5c01e515442448633ab5 (diff)
downloadfreertos-e90329865b5e0a8ed6391a2d05ef863139dd5533.tar.gz
Correct comment error that was replicated on many different main_full.c files.
git-svn-id: http://svn.code.sf.net/p/freertos/code/trunk@2438 1d2547de-c912-0410-9cb9-b8ca96c0e9e2
Diffstat (limited to 'FreeRTOS/Demo/CORTEX_M7_STM32F7_STM32756G-EVAL_IAR_Keil')
-rw-r--r--FreeRTOS/Demo/CORTEX_M7_STM32F7_STM32756G-EVAL_IAR_Keil/Full_Demo/main_full.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/FreeRTOS/Demo/CORTEX_M7_STM32F7_STM32756G-EVAL_IAR_Keil/Full_Demo/main_full.c b/FreeRTOS/Demo/CORTEX_M7_STM32F7_STM32756G-EVAL_IAR_Keil/Full_Demo/main_full.c
index b265a294c..88818a693 100644
--- a/FreeRTOS/Demo/CORTEX_M7_STM32F7_STM32756G-EVAL_IAR_Keil/Full_Demo/main_full.c
+++ b/FreeRTOS/Demo/CORTEX_M7_STM32F7_STM32756G-EVAL_IAR_Keil/Full_Demo/main_full.c
@@ -148,15 +148,15 @@
/* A block time of zero simply means "don't block". */
#define mainDONT_BLOCK ( 0UL )
-/* The period after which the check timer will expire, in ms, provided no errors
-have been reported by any of the standard demo tasks. ms are converted to the
-equivalent in ticks using the portTICK_PERIOD_MS constant. */
-#define mainNO_ERROR_CHECK_TASK_PERIOD ( 3000UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, provided no errors have been reported by
+any of the standard demo tasks. ms are converted to the equivalent in ticks
+using the pdMS_TO_TICKS() macro constant. */
+#define mainNO_ERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 3000UL )
-/* The period at which the check timer will expire, in ms, if an error has been
-reported in one of the standard demo tasks. ms are converted to the equivalent
-in ticks using the portTICK_PERIOD_MS constant. */
-#define mainERROR_CHECK_TASK_PERIOD ( 200UL / portTICK_PERIOD_MS )
+/* The period of the check task, in ms, if an error has been reported in one of
+the standard demo tasks. ms are converted to the equivalent in ticks using the
+pdMS_TO_TICKS() macro. */
+#define mainERROR_CHECK_TASK_PERIOD pdMS_TO_TICKS( 200UL )
/* Parameters that are passed into the register check tasks solely for the
purpose of ensuring parameters are passed into tasks correctly. */
@@ -411,7 +411,7 @@ static void prvRegTestTaskEntry1( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}
@@ -429,7 +429,7 @@ static void prvRegTestTaskEntry2( void *pvParameters )
}
/* The following line will only execute if the task parameter is found to
- be incorrect. The check timer will detect that the regtest loop counter is
+ be incorrect. The check task will detect that the regtest loop counter is
not being incremented and flag an error. */
vTaskDelete( NULL );
}